@@ -27,41 +27,22 @@ FilterCorrelation = R6Class("FilterCorrelation",
   public = list(
 
     #' @description Create a FilterCorrelation object.
-    #' @param id (`character(1)`)\cr
-    #'   Identifier for the filter.
-    #' @param task_type (`character()`)\cr
-    #'   Types of the task the filter can operator on. E.g., `"classif"` or
-    #'   `"regr"`.
-    #' @param param_set ([paradox::ParamSet])\cr
-    #'   Set of hyperparameters.
-    #' @param feature_types (`character()`)\cr
-    #'   Feature types the filter operates on.
-    #'   Must be a subset of
-    #'   [`mlr_reflections$task_feature_types`][mlr3::mlr_reflections].
-    #' @param packages (`character()`)\cr
-    #'   Set of required packages.
-    #'   Note that these packages will be loaded via [requireNamespace()], and
-    #'   are not attached.
-    initialize = function(id = "correlation",
-      task_type = "regr",
+    initialize = function() {
       param_set = ParamSet$new(list(
-        ParamFct$new("use",
-          default = "everything",
+        ParamFct$new("use", default = "everything",
           levels = c(
             "everything", "all.obs", "complete.obs", "na.or.complete",
             "pairwise.complete.obs")),
-        ParamFct$new("method",
-          default = "pearson",
+        ParamFct$new("method", default = "pearson",
           levels = c("pearson", "kendall", "spearman"))
-      )),
-      packages = "stats",
-      feature_types = c("integer", "numeric")) {
+      ))
+
       super$initialize(
-        id = id,
-        task_type = task_type,
+        id = "correlation",
+        task_type = "regr",
         param_set = param_set,
-        feature_types = feature_types,
-        packages = packages,
+        feature_types = c("integer", "numeric"),
+        packages = "stats",
         man = "mlr3filters::mlr_filters_correlation"
       )
     }
