@@ -14,7 +14,7 @@
 #' @examples
 #' task = mlr3::tsk("iris")
 #' filter = flt("disr")
-#' filter$calculate(task, nfeat = 2)
+#' filter$calculate(task)
 #' as.data.table(filter)
 FilterDISR = R6Class("FilterDISR",
   inherit = Filter,
@@ -41,7 +41,7 @@ FilterDISR = R6Class("FilterDISR",
 
   private = list(
     .calculate = function(task, nfeat) {
-      call_praznik(self, task, praznik::DISR)
+      call_praznik(self, task, praznik::DISR, nfeat)
     }
   )
 )
